Contributing, Reporting Bugs and Requesting Features
====================================================

In which ways I can contribute?
-------------------------------
If you come across any issues, or have feature suggestions you would like to see in piqueserver, please inform us in our `Issue Tracker <https://github.com/piqueserver/piqueserver/issues>`_.

.. tip:: Before reporting your problem or submitting a suggestion, search the `Issue Tracker <https://github.com/piqueserver/piqueserver/issues>`_ for similar issues.

Reporting bugs
---------------
When reporting bugs, please be as clear and detailed as possible. This way, we can work faster by saving time that would otherwise be spent asking questions and waiting between responses.

Common relevant information include:

* Operating System (Windows, Mac OS X, GNU/Linux *distro*)
* piqueserver version
* Expected behaviour and what happened instead
* Your console output containing the error

Submitting code changes in piqueserver
--------------------------------------
You can search inside these docs for information that might be relevant to your desired code changes.
If you can't find any, feel free to reach to us in chat ;).

Be sure to also check our :doc:`Developer guidelines <contributing-developer>`
